"""Test configuration and fixtures."""

import os
import pytest
import pytest_asyncio
import fakeredis.aioredis
from typing import AsyncGenerator
import asyncio
from SYS_RESEARCH.web.app import init_app
from SYS_RESEARCH.security.research_vault import ResearchVault


@pytest.fixture(autouse=True)
def setup_test_env():
    """Set up test environment variables."""
    os.environ["GLASSNODE_KEY"] = "test_glassnode_key"
    os.environ["CRYPTOQUANT_KEY"] = "test_cryptoquant_key"
    os.environ["NEWSAPI_KEY"] = "test_newsapi_key"
    os.environ["ROSE_RESEARCH_KEY"] = "test_rose_research_key"


@pytest.fixture
async def redis_client() -> AsyncGenerator:
    """Create a fake Redis client for testing."""
    client = fakeredis.aioredis.FakeRedis()
    yield client
    await client.close()


@pytest.fixture(scope='function')
def event_loop():
    policy = asyncio.WindowsSelectorEventLoopPolicy()
    loop = policy.new_event_loop()
    yield loop
    loop.close()


@pytest_asyncio.fixture(scope="session")
async def app():
    """Create a test application instance."""
    app = await init_app()
    yield app
    await app.cleanup()


@pytest_asyncio.fixture(scope="session")
async def vault():
    """Create a test vault instance."""
    vault = ResearchVault()
    await vault.initialize()
    yield vault
    await vault.cleanup()
