import pytest
import asyncio
from SYS_RESEARCH.core_integration import ResearchCore

@pytest.fixture
def core():
    return ResearchCore()

@pytest.fixture(autouse=True)
async def cleanup(core):
    yield
    for worker in core.workers:
        worker.cancel()
    await asyncio.sleep(0)

@pytest.mark.asyncio
async def test_parallel_search(core):
    test_queries = [f"test_query_{i}" for i in range(10)]
    
    await core.parallel_search(test_queries)
    progress = core.get_progress()
    
    assert progress['completed'] == 10
    assert progress['failed'] == 0
    assert progress['percentage'] == 100.0
    
    # After test execution
    stored = await core.data_lake.retrieve_results()
    assert len(stored) == 10
