import unittest
import numpy as np
from app.core.risk_management import RiskManager, PositionSizingConfig


class TestRiskManagement(unittest.TestCase):
    def setUp(self):
        self.risk_manager = RiskManager(initial_capital=100000)
        self.config = PositionSizingConfig()

    def test_fixed_fraction(self):
        self.config.mode = "fixed"
        self.config.max_risk = 0.02
        size = self.risk_manager.calculate_position_size(100.0, 0.1, self.config)
        self.assertAlmostEqual(size, 2000.0)

    def test_kelly_criterion(self):
        self.config.mode = "kelly"
        size = self.risk_manager.calculate_position_size(
            100.0, 0.1, self.config, win_rate=0.6, win_loss_ratio=2.0
        )
        expected = (0.6 * 2 - 0.4) / 2 * 100000
        self.assertAlmostEqual(size, expected)

    def test_volatility_scaling(self):
        self.config.mode = "volatility"
        size = self.risk_manager.calculate_position_size(100.0, 0.05, self.config)
        expected = (100000 * 0.1) / (0.05 * np.sqrt(20))
        self.assertAlmostEqual(size, expected)


if __name__ == "__main__":
    unittest.main()
